@@ -248,7 +248,9 @@ class XAPIAN_VISIBILITY_DEFAULT Enquire {
 	 *  @param spy       The MatchSpy subclass to add.  The caller must
 	 *                   ensure that this remains valid while the Enquire
 	 *                   object remains active, or until @a
-	 *                   clear_matchspies() is called.
+	 *                   clear_matchspies() is called, or else allocate
+	 *                   the MatchSpy object with new and then disown it by
+	 *                   calling spy->release() before passing it in.
 	 */
 	void add_matchspy(MatchSpy * spy);
 
@@ -268,14 +270,16 @@ class XAPIAN_VISIBILITY_DEFAULT Enquire {
 	 *
 	 *  If you don't call this method, the default is as if you'd used:
 	 *
-	 *  get_expansion_scheme("trad");
+	 *  set_expansion_scheme("prob");
 	 *
 	 *  @param eweightname_  A string in lowercase specifying the name of
 	 *                       the scheme to be used. The following schemes
 	 *                       are currently available:
-	 *                       "bo1" : The Bo1 scheme for query expansion.
-	 *                       "trad" : The TradWeight scheme for query expansion.
-	 *  @param expand_k_ The parameter required for TradWeight query expansion.
+	 *                       * "bo1": Bose-Einstein 1 model from the Divergence
+	 *			          From Randomness framework.
+	 *                       * "prob" : Probabilistic model (since 1.4.26).
+	 *                       * "trad" : Older alias for "prob".
+	 *  @param expand_k_ Parameter k for probabilistic query expansion.
 	 *                   A default value of 1.0 is used if none is specified.
 	 */
 	void set_expansion_scheme(const std::string &eweightname_,
